@@ -172,9 +172,6 @@ class OpenPhi:
             assert (size[0] > 0 and isinstance(size[0], int)), "Size should be a positive integer."
             assert (size[1] > 0 and isinstance(size[1], int)), "Size should be a positive integer."
 
-            # Figure out what level to use to not exceed specified maximum size.
-            dims = np.array(self.level_dimensions)
-
             # Take the first index (highest res level) where both X and Y dimension
             # are smaller or equal to the specified maximum dimensions.
             # If there is no such level, take the lowest res level.
@@ -261,11 +258,13 @@ class OpenPhi:
             step = self.level_downsamples[level]
 
             # Coordinates of the region in full-res system
-            # x-start, x-end, y-start, y-end.
-            roicoords = [[location[0],
-                        location[0] + size[0] * step - 2 ** level,
-                        location[1],
-                        location[1] + size[1] * step - 2 ** level,
+            # x-start, x-end, y-start, y-end. Make sure the x and y coordinate
+            # are valid on the resolution level i.e. divisible by the level's 
+            # pixel spacing. Ensure this by removing the modulus.
+            roicoords = [[location[0] - location[0] % step,
+                        location[0] - location[0] % step + size[0] * step - 2 ** level,
+                        location[1] - location[1] % step,
+                        location[1] - location[1] % step + size[1] * step - 2 ** level,
                         level]]
 
             image = self.__read_pixeldata(roicoords, level)
